@@ -6,10 +6,6 @@ from .tags import (
     __head__,
 )
 from .main import *
-from .main import (
-    __requests__,
-    __DOM__,
-)
 from .__app__ import *
 from .__app__ import (
     __APP__,
